@@ -1,5 +1,5 @@
 package Test::BDD::Cucumber::StepContext;
-$Test::BDD::Cucumber::StepContext::VERSION = '0.71';
+$Test::BDD::Cucumber::StepContext::VERSION = '0.72';
 use Moo;
 use Types::Standard qw( Bool Str HashRef ArrayRef InstanceOf );
 use List::Util qw( first );
@@ -10,7 +10,7 @@ Test::BDD::Cucumber::StepContext - Data made available to step definitions
 
 =head1 VERSION
 
-version 0.71
+version 0.72
 
 =head1 DESCRIPTION
 
@@ -340,7 +340,7 @@ sub dispatch {
     my $new_context = $self->new(
         {
             executor => $self->executor,
-            ( $data    ? ( _data   => $data )    : () ),
+            ( $data    ? ( data   => $data )    : () ),
             ( $columns ? ( columns => $columns ) : () ),
             stash => {
                 feature  => $self->stash->{'feature'},
@@ -433,7 +433,8 @@ Peter Sergeant C<pete@clueball.com>
 
 =head1 LICENSE
 
-Copyright 2011-2016, Peter Sergeant; Licensed under the same terms as Perl
+  Copyright 2019-2020, Erik Huelsmann
+  Copyright 2011-2019, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
 
